@@ -12,4 +12,5 @@
 
 from flaskext.auth.auth import Auth, AuthUser, login, logout, get_current_user,\
         login_required, encrypt
-from flaskext.auth.permissions import has_permission, permission_required
+from flaskext.auth.permissions import has_permission, permission_required, \
+        Role, Permission
